"""
The core module provides functions for processing and visualizing
binaries using binwalk for the heavy lifting.
"""

from typing import IO
import binwalk.core.compat as compat
from . import MAGIC


def process_file(bin_file: IO[str]) -> None:
    """
    process_file(bin: IO[str]) -> None

    Processes a binary file and reads its data using the given binary input stream.

    :param bin: A file object representing the binary input stream.
    :type bin: IO[str]
    :returns: None
    """
    with open(bin_file, "rb") as bin_data:
        data = bin_data.read()

    scan_length = len(data)
    results = []

    for offset, description in compat.iteritems(MAGIC.scan(data, length=scan_length)):
        results.append((offset, description))

    for offset, description in results:
        print(f"Found signature {description} at offset {offset}")
